//
// tardy - a tar post-processor
// Copyright (C) 2011, 2012 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#include <libtardy/rcstring.h>


bool
str_equal(string_t *s1, string_t *s2)
{
    return (s1 == s2);
}


bool
operator == (const rcstring &lhs, const rcstring &rhs)
{
    string_t *s1 = lhs.p ? lhs.p : str_from_c("");
    string_t *s2 = rhs.p ? rhs.p : str_from_c("");
    return str_equal(s1, s2);
}


bool
operator != (const rcstring &lhs, const rcstring &rhs)
{
    string_t *s1 = lhs.p ? lhs.p : str_from_c("");
    string_t *s2 = rhs.p ? rhs.p : str_from_c("");
    return !str_equal(s1, s2);
}


// vim: set ts=8 sw=4 et :
